@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0115';
+our $VERSION = '0.0116';
 
 use strict;
 use warnings;
@@ -119,7 +119,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0115
+version 0.0116
 
 =head1 SYNOPSIS
 
@@ -181,18 +181,18 @@ the scope of the coderef that is returned by the part.
 =head2 Hints
 
 B<Linux>:
-If your distro does not install a service, you can use timidity in
-daemon mode: C<timidity -iAD>. Also, FluidSynth is an alternative.
+If your distro does not install a service, you can use FluidSynth:
+C<fluidsynth -a alsa -m alsa_seq some-soundfont.sf2>
+Or try Timidity in daemon mode: C<timidity -iAD>, but YMMV, TBH.
 
 B<MacOS>:
 You can use FluidSynth like this:
 C<fluidsynth -a coreaudio -m coremidi -g 1.0 some-soundfont.sf2>
-Also, you can use Timidity. You can also use a digital audio
-workstation (DAW) like Logic, with a software synth track selected.
-If you wish, you can get General MIDI via "DLSMusicDevice" within a
-DAW. To do this, you will need a soundfont in
-C<~/Library/Audio/Sounds/Banks/> and DLSMusicDevice open in your DAW
-with the soundfont selected.
+Also, you can use Timidity, as above. A digital audio workstation
+(DAW) like Logic, with a software synth track selected, will work. And
+if you wish, you can get General MIDI with a "DLSMusicDevice" track
+open, and a soundfont in C<~/Library/Audio/Sounds/Banks/>. Make sure
+the soundfont is selected for the track.
 
 B<Windows>:
 This should I<just work> out of the box.
